//**********************************************************************
//  OBISHelper
//
//  i-cube, Christian Aymon, 1376 Goumoens-la-Ville, Switzerland
//          infos@icube.ch
//
// (C)Copyright 2010-2012
//**********************************************************************
#ifndef OBISHelper_Interface_h
#define OBISHelper_Interface_h
/*

OBISHelper dll usage
++++++++++++++++++++

Preriquiste
-----------

If needed, create the csv files for the different available media.

1) Goto http://www.dlms.com/documentation/listofstandardobiscodesandmaintenanceproces/index.html
2) Download the latest Object_defs_xxxx file
3) Load the xls file in Excel
4) Select the ''Abstract'' sheet
5) Do File/Save As set ''0.csv'' as the file name. In the drop-down-box ''Save as type:'' select CSV (Comma delimited).
6) Repeat for the sheets ''Electricity'' (1.csv) and ''Gas'' (7.csv)

In the client application (CA)
------------------------------

1) call OBISHelperInitialize() passing a reference to the full path of the directory where the x.csv files are located.

2) call OBISHelperText to get the text of the passed OBIS code

*/


#ifdef OBISHELPER_EXPORTS
#define OBISHELPER_API __declspec(dllexport)
#else
#define OBISHELPER_API
#endif

extern "C" OBISHELPER_API bool OBISHelperInitialize(const char * CSVDirectory);
// Initializes OBISHelper dll. CSVDirectory is a reference to a string containing the full path 
// of the directory where the x.csv files are located.
// Returns TRUE if success, else returns FALSE. 

extern "C" OBISHELPER_API bool OBISHelperText(const char * OBISCode, char * OBISText, int MaxOBISTextSize);
// Get the text of OBISCode. The text is returned in the buffer referenced by OBISText with
// a maximal size of MaxOBISTextSize. Returns TRUE if success else returns FALSE.
// OBISCode can be in dotted notation, for example 0.0.1.0.0.255 or in hex-notation 0000010000FF.

extern "C" OBISHELPER_API const char * OBISHelperLastErrorMessage();
// Returns an error string. Can be called when OBISHelperInitialize or OBISHelperText
// return FALSE.

extern "C" OBISHELPER_API const char * OBISHelperVersion();
// Returns a string with the version number of the dll.


#endif  // OBISHelper_Interface_h
